@@ -8,8 +8,10 @@ from dkist_processing_common.tasks import ScienceTaskL0ToL1Base
 
 class GenerateCalibratedData(ScienceTaskL0ToL1Base):
     def run(self):
+        count = 1  # keep a running count to increment the dsps repeat number
         for path, hdu in self.fits_data_read_hdu(tags=Tag.input()):
             header = hdu.header
+            header["DSPSNUM"] = count
             data = hdu.data
             output_hdu = fits.PrimaryHDU(data=data, header=header)
             output_hdul = fits.HDUList([output_hdu])
@@ -19,6 +21,7 @@ class GenerateCalibratedData(ScienceTaskL0ToL1Base):
                     Tag.calibrated(),
                     Tag.frame(),
                     Tag.stokes("I"),
-                    Tag.dsps_repeat(header["DSPSNUM"]),
+                    Tag.dsps_repeat(count),
                 ],
             )
+            count += 1
