@@ -33,5 +33,9 @@ class AssembleTestMovie(AssembleMovie):
     A shell to extend the AssembleMovie class for the end-to-end test.
     """
 
+    @property
+    def fits_parsing_class(self):
+        return L1FitsAccess
+
     def write_overlay(self, draw: ImageDraw, fits_obj: L1FitsAccess) -> None:
         pass
